#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Do something for uninstalling the landisk-cloud-common package."""


from ionas import request
from fal_info import (FAL_SERVICECTRL_PATH, Results, ReqTypes)

NASDSYNC2_NAME = "nasdsync2"
SERVICELIST_NAME = "servicelist"
PACKAGE_SERVICE_NAME_XPATH = SERVICELIST_NAME + \
                '/service/name[text()="%s"]' % (NASDSYNC2_NAME, )
PACKAGE_SERVICELIST_IN_DISK_XPATH = \
        'categorylist/category/name[text()="disk"]/../servicelist'
PACKAGE_SERVICELIST_IN_SHARE_XPATH = \
        'categorylist/category/name[text()="share"]/../servicelist'
PACKAGE_SERVICE_XML = '<service enable="true"><name>%s</name></service>' % \
                        (NASDSYNC2_NAME, )
PACKAGE_SERVICE_IN_CATEGORY_XML = \
        '<service><name>%s</name></service>' % (NASDSYNC2_NAME, )

SERVICECTRL_REQ_XML = """<servicectrl>
    <servicelist>
        <service><name>%s</name></service>
    </servicelist>
</servicectrl>
""" % (NASDSYNC2_NAME, )


def __send_request(target, type, body=""):
    """Send request entry to "target"."""

    entry = request.Entry(type, body)
    return request.Request(target).request(entry).get_entry()


def try_start_service():
    """Try start service for the package."""

    try:
        __send_request(FAL_SERVICECTRL_PATH, ReqTypes.START,
                            SERVICECTRL_REQ_XML)
    except:
        # Ignore error
        pass


def try_stop_service():
    """Try stop service for the package."""

    try:
        __send_request(FAL_SERVICECTRL_PATH, ReqTypes.STOP,
                            SERVICECTRL_REQ_XML)
    except:
        # Ignore error
        pass


#
# Main
#

try_stop_service()
